@@ -1,6 +1,6 @@
 package DBD::Gofer::Transport::Base;
 
-#   $Id: Base.pm 11427 2008-06-16 15:24:46Z timbo $
+#   $Id: Base.pm 14120 2010-06-07 19:52:19Z H.Merijn $
 #
 #   Copyright (c) 2007, Tim Bunce, Ireland
 #
@@ -12,7 +12,7 @@ use warnings;
 
 use base qw(DBI::Gofer::Transport::Base);
 
-our $VERSION = sprintf("0.%06d", q$Revision: 11427 $ =~ /(\d+)/o);
+our $VERSION = sprintf("0.%06d", q$Revision: 14120 $ =~ /(\d+)/o);
 
 __PACKAGE__->mk_accessors(qw(
     trace
@@ -288,6 +288,8 @@ sub _store_response_in_cache {
 
 1;
 
+__END__
+
 =head1 NAME
 
 DBD::Gofer::Transport::Base - base class for DBD::Gofer client transports
@@ -356,7 +358,7 @@ A retry won't be allowed if the number of previous retries has reached C<go_retr
 
 =head1 TRACING
 
-Tracing of gofer requests and reponses can be enabled by setting the
+Tracing of gofer requests and responses can be enabled by setting the
 C<DBD_GOFER_TRACE> environment variable. A value of 1 gives a reasonably
 compact summary of each request and response. A value of 2 or more gives a
 detailed, and voluminous, dump.
@@ -364,13 +366,31 @@ detailed, and voluminous, dump.
 The trace is written using DBI->trace_msg() and so is written to the default
 DBI trace output, which is usually STDERR.
 
+=head1 METHODS
+
+I<This section is currently far from complete.>
+
+=head2 response_retry_preference
+
+  $retry = $transport->response_retry_preference($request, $response);
+
+The response_retry_preference is called by DBD::Gofer when considering if a
+request should be retried after an error.
+
+Returns true (would like to retry), false (must not retry), undef (no preference).
+
+If a true value is returned in the form of a CODE ref then, if DBD::Gofer does
+decide to retry the request, it calls the code ref passing $retry_count, $retry_limit.
+Can be used for logging and/or to implement exponential backoff behaviour.
+Currently the called code must return using C<return;> to allow for future extensions.
+
 =head1 AUTHOR
 
 Tim Bunce, L<http://www.tim.bunce.name>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007, Tim Bunce, Ireland. All rights reserved.
+Copyright (c) 2007-2008, Tim Bunce, Ireland. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
