@@ -229,11 +229,9 @@ $DBD::Proxy::db::imp_data_size = 0;
 # in a way that might not be visible on the client, ie begin_work -> AutoCommit.
 
 sub commit;
-sub connected;
 sub rollback;
 sub ping;
 
-
 use vars qw(%ATTR $AUTOLOAD);
 
 # inherited: STORE / FETCH against this class.
@@ -295,6 +293,9 @@ sub DESTROY {
     $dbh->disconnect if $dbh->SUPER::FETCH('Active');
 }
 
+
+sub connected { } # client-side not server-side, RT#75868
+
 sub disconnect ($) {
     my ($dbh) = @_;
 
